@@ -4,10 +4,10 @@
 
 #include "mapinfodata.h"
 
-#include "salalib/pointmap.h"
-#include "salalib/shapemap.h"
+#include "../pointmap.h"
+#include "../shapemap.h"
 
-#include "genlib/stringutils.h"
+#include "../genlib/stringutils.h"
 
 #include <numeric>
 
