@@ -12,13 +12,8 @@ struct TopoMetSegmentRef {
     double dist;
     int previous;
     bool done;
-    TopoMetSegmentRef(int r = -1, int d = -1, double di = 0.0, int p = -1) {
-        ref = r;
-        dir = d;
-        dist = di;
-        previous = p;
-        done = false;
-    }
+    TopoMetSegmentRef(int r = -1, int d = -1, double di = 0.0, int p = -1)
+        : ref(r), dir(d), dist(di), previous(p), done(false) {}
 };
 
 // should be double not float!
@@ -26,17 +21,11 @@ struct TopoMetSegmentRef {
 struct TopoMetSegmentChoice {
     double choice;
     double wchoice;
-    TopoMetSegmentChoice() {
-        choice = 0.0;
-        wchoice = 0.0;
-    }
+    TopoMetSegmentChoice() : choice(0.0), wchoice(0.0) {}
 };
 
 struct SegInfo {
     double length;
     int layer;
-    SegInfo() {
-        length = 0.0f;
-        layer = 0;
-    }
+    SegInfo() : length(0.0f), layer(0) {}
 };
