@@ -4,9 +4,10 @@
 
 #pragma once
 
-#include "salalib/ianalysis.h"
-#include "salalib/pixelref.h"
-#include "salalib/pointmap.h"
+#include "../ianalysis.h"
+#include "../pixelref.h"
+#include "../pointmap.h"
+
 #include <iomanip>
 
 class VGAIsovistZone : public IAnalysis {
