@@ -7,9 +7,10 @@
 #pragma once
 
 #include "ivgametric.h"
-#include "salalib/pointmap.h"
 
-#include "genlib/stringutils.h"
+#include "../pointmap.h"
+
+#include "../genlib/stringutils.h"
 
 class VGAMetric : public IVGAMetric {
   private:
